@@ -91,12 +91,15 @@ list_resource (GResource   *resource,
 
       len = MIN (strlen (child), strlen (prefix));
       if (strncmp (child, prefix, len) != 0)
-        continue;
+        {
+          g_free (child);
+          continue;
+        }
 
       if (g_resource_get_info (resource, child, 0, &size, &flags, NULL))
         {
           if (details)
-            g_print ("%s%s%6"G_GSIZE_FORMAT " %s %s\n", section, section[0] ? " " : "", size, flags & G_RESOURCE_FLAGS_COMPRESSED ? "c" : "u", child);
+            g_print ("%s%s%6"G_GSIZE_FORMAT " %s %s\n", section, section[0] ? " " : "", size, (flags & G_RESOURCE_FLAGS_COMPRESSED) ? "c" : "u", child);
           else
             g_print ("%s\n", child);
         }
@@ -126,10 +129,6 @@ extract_resource (GResource   *resource,
         g_printerr ("Data truncated\n");
       g_bytes_unref (bytes);
     }
-  else
-    {
-      g_printerr ("Can't find resource path %s\n", path);
-    }
 }
 
 /* Elf functions {{{1 */
@@ -228,10 +227,16 @@ resource_from_section (GElf_Shdr *shdr,
   if (contents != MAP_FAILED)
     {
       GBytes *bytes;
+      GError *error = NULL;
 
       bytes = g_bytes_new_static (contents + page_offset, shdr->sh_size);
-      resource = g_resource_new_from_data (bytes, NULL);
+      resource = g_resource_new_from_data (bytes, &error);
       g_bytes_unref (bytes);
+      if (error)
+        {
+          g_printerr ("%s\n", error->message);
+          g_error_free (error);
+        }
     }
   else
     {
@@ -314,7 +319,10 @@ extract_resource_cb (GElf_Shdr   *shdr,
   extract_resource (resource, d->path);
   g_resource_unref (resource);
 
-  return FALSE;
+  if (d->section)
+    return FALSE;
+
+  return TRUE;
 }
 
 static void
@@ -395,7 +403,6 @@ cmd_list (const gchar *file,
   GResource *resource;
 
 #ifdef HAVE_LIBELF
-
   Elf *elf;
   int fd;
 
