@@ -39,13 +39,20 @@
  * It contains functions to do some of the UNIX socket specific
  * functionality like passing file descriptors.
  *
- * Note that <filename>&lt;gio/gunixconnection.h&gt;</filename> belongs to
- * the UNIX-specific GIO interfaces, thus you have to use the
- * <filename>gio-unix-2.0.pc</filename> pkg-config file when using it.
+ * Note that `<gio/gunixconnection.h>` belongs to the UNIX-specific
+ * GIO interfaces, thus you have to use the `gio-unix-2.0.pc`
+ * pkg-config file when using it.
  *
  * Since: 2.22
  */
 
+/**
+ * GUnixConnection:
+ *
+ * #GUnixConnection is an opaque data structure and can only be accessed
+ * using the following functions.
+ **/
+
 G_DEFINE_TYPE_WITH_CODE (GUnixConnection, g_unix_connection,
 			 G_TYPE_SOCKET_CONNECTION,
   g_socket_connection_factory_register_type (g_define_type_id,
@@ -156,7 +163,10 @@ g_unix_connection_receive_fd (GUnixConnection  *connection,
       gint i;
 
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   _("Expecting 1 control message, got %d"), nscm);
+        ngettext("Expecting 1 control message, got %d",
+                 "Expecting 1 control message, got %d",
+                 nscm),
+        nscm);
 
       for (i = 0; i < nscm; i++)
         g_object_unref (scms[i]);
@@ -187,7 +197,10 @@ g_unix_connection_receive_fd (GUnixConnection  *connection,
       gint i;
 
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-		   _("Expecting one fd, but got %d\n"), nfd);
+                   ngettext("Expecting one fd, but got %d\n",
+                            "Expecting one fd, but got %d\n",
+                            nfd),
+                   nfd);
 
       for (i = 0; i < nfd; i++)
         close (fds[i]);
@@ -396,7 +409,7 @@ g_unix_connection_send_credentials_async (GUnixConnection      *connection,
   GTask *task;
 
   task = g_task_new (connection, cancellable, callback, user_data);
-
+  g_task_set_source_tag (task, g_unix_connection_send_credentials_async);
   g_task_run_in_thread (task, send_credentials_async_thread);
 }
 
@@ -545,7 +558,9 @@ g_unix_connection_receive_credentials (GUnixConnection      *connection,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_FAILED,
-                       _("Expecting 1 control message, got %d"),
+                       ngettext("Expecting 1 control message, got %d",
+                                "Expecting 1 control message, got %d",
+                                nscm),
                        nscm);
           goto out;
         }
@@ -655,7 +670,7 @@ g_unix_connection_receive_credentials_async (GUnixConnection      *connection,
   GTask *task;
 
   task = g_task_new (connection, cancellable, callback, user_data);
-
+  g_task_set_source_tag (task, g_unix_connection_receive_credentials_async);
   g_task_run_in_thread (task, receive_credentials_async_thread);
 }
 
