@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Simon McVittie <simon.mcvittie@collabora.co.uk>
  */
@@ -73,8 +71,8 @@ run_proxy_thread (gpointer data)
       GError *error = NULL;
       GVariant *ret;
 
-      if (!g_test_quiet ())
-        g_print (".");
+      if (g_test_verbose ())
+        g_printerr (".");
 
       proxy = g_dbus_proxy_new_sync (connection,
                                      G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START |
@@ -234,8 +232,8 @@ test_proxy (void)
   /* TODO: should call session_bus_down() but that requires waiting
    * for all the oustanding method calls to complete...
    */
-  if (!g_test_quiet ())
-    g_print ("\n");
+  if (g_test_verbose ())
+    g_printerr ("\n");
 }
 
 int
